@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-11-29 19:28:01
+@LastEditTime: 2021-11-29 20:24:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,13 +22,19 @@ class HorseracelampListHandler(ClientBaseHandler):
         :param act_id: 活动标识
         :param module_id: 活动模块标识
         :param page_size: 条数
+        :param is_search_module: 是否查询活动模块
         :return:
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", -1))
-        page_size = int(self.get_param("page_size", 10))
+        page_size = int(self.get_param("page_size", 30))
+        is_search_module = int(self.get_param("is_search_module", 0))
+        if is_search_module == 0:
+            is_search_module = False
+        else:
+            is_search_module = True
 
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
@@ -37,7 +43,7 @@ class HorseracelampListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
 
         order_base_model = OrderBaseModel(context=self)
-        horseracelamp_list = self.business_process_executed(order_base_model.get_horseracelamp_list(act_id, module_id, page_size), ref_params={})
+        horseracelamp_list = self.business_process_executed(order_base_model.get_horseracelamp_list(act_id, module_id,is_search_module, page_size), ref_params={})
         return self.response_json_success(horseracelamp_list)
 
 
@@ -139,8 +145,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by","id desc")
-        is_search_roster = self.get_param("is_search_roster", False)
-        is_search_roster = self.get_param("is_search_roster", 0)
+        is_search_roster = int(self.get_param("is_search_roster", 0))
         if is_search_roster == 0:
             is_search_roster = False
         else:
@@ -153,9 +158,9 @@ class PrizeOrderListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
 
         order_base_model = OrderBaseModel(context=self)
-        page_list, total = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=True)
+        page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=True)
         ref_params = {}
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
 
 
@@ -168,6 +173,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         """
         :description: 用户中奖记录列表
         :param act_id：活动标识
+        :param module_id：活动模块标识
         :param user_id：用户标识
         :param order_no：订单号
         :param goods_type：物品类型（1虚拟2实物）
@@ -183,6 +189,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
         app_id = self.get_source_app_id()
         open_id = self.get_param("open_id")
         act_id = int(self.get_param("act_id", 0))
+        module_id = int(self.get_param("module_id", 0))
         user_id = self.get_user_id()
         order_no = self.get_param("order_no")
         goods_type = int(self.get_param("goods_type", -1))
@@ -198,9 +205,9 @@ class PrizeRosterListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
 
         order_base_model = OrderBaseModel(context=self)
-        page_list, total = order_base_model.get_prize_roster_list(app_id=app_id, act_id=act_id, user_id=user_id, open_id=open_id, order_no=order_no, goods_type=goods_type, prize_type=prize_type, logistics_status=logistics_status, prize_status=prize_status, pay_status=pay_status, page_size=page_size, page_index=page_index)
+        page_info = order_base_model.get_prize_roster_list(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, open_id=open_id, order_no=order_no, goods_type=goods_type, prize_type=prize_type, logistics_status=logistics_status, prize_status=prize_status, pay_status=pay_status, page_size=page_size, page_index=page_index)
         ref_params = {}
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
+        page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
 
 
