@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-12-15 10:39:36
+@LastEditTime: 2021-12-21 10:26:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -296,8 +296,9 @@ class AssetLogListHandler(ClientBaseHandler):
         :description: 资产流水记录
         :param act_id：活动标识
         :param tb_user_id：用户标识
-        :param asset_type：资产类型(1-次数2-积分3-价格档位)
+        :param asset_type：资产类型(1-次数2-积分3-价格档位))
         :param asset_object_id：资产对象标识
+        :param operate_type：操作类型(0累计 1消耗
         :param page_size：条数
         :param page_index：页数
         :return list
@@ -311,6 +312,7 @@ class AssetLogListHandler(ClientBaseHandler):
         page_size = int(self.get_param("page_size", 20))
         asset_type = int(self.get_param("asset_type", 0))
         asset_object_id = self.get_param("asset_object_id")
+        operate_type = int(self.get_param("operate_type", -1))
 
         field = "*"
         invoke_result_data = self.business_process_executing()
@@ -319,7 +321,7 @@ class AssetLogListHandler(ClientBaseHandler):
         else:
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
-        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field)
+        page_info = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field, is_cache=True, operate_type=operate_type)
         ref_params = {}
         page_info.data = self.business_process_executed(page_info.data, ref_params)
         return self.response_json_success(page_info)
