@@ -2,9 +2,9 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-11-19 10:07:46
+@LastEditTime: 2021-11-29 16:40:13
 @LastEditors: HuangJianYi
-@Description: 
+@Description: 奖品模块
 """
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.handlers.frame_base import *
@@ -120,6 +120,8 @@ class SaveActPrizeHandler(ClientBaseHandler):
             self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data["new"].id)
 
 
@@ -150,6 +152,7 @@ class ActPrizeListHandler(ClientBaseHandler):
         condition = ""
         params = []
         order_by = "create_date desc"
+        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
@@ -157,11 +160,11 @@ class ActPrizeListHandler(ClientBaseHandler):
             condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
-
+            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
-        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, is_cache=False)
+        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
         return self.response_json_success(page_info)
