@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2021-10-09 18:21:02
+@LastEditTime: 2021-11-17 17:53:59
 @LastEditors: HuangJianYi
 :Description: 数据库基础操作类
 """
@@ -147,13 +147,14 @@ class CacheModel(BaseModel):
         redis_init = self.__redis_init()
         return redis_init.delete(self.__get_dependency_key(dependency_key))
 
-    def get_cache_list(self, where='', group_by='', order_by='', limit='', params=None,dependency_key='', cache_expire=600):
+    def get_cache_list(self, where='', group_by='', order_by='', limit='', field="*", params=None,dependency_key='', cache_expire=600):
         """
         :Description: 根据条件获取列表
         :param where: 数据库查询条件语句
         :param group_by: GROUP BY 语句
         :param order_by:  ORDER BY 语句
         :param limit:  LIMIT 语句
+        :param field: 查询字段 
         :param params: 参数化查询参数
         :param dependencyKey: 依赖键
         :param cache_expire: 缓存时间（单位秒）
@@ -168,7 +169,7 @@ class CacheModel(BaseModel):
             order_by = " ORDER BY " + order_by
         if limit:
             limit = " LIMIT "+str(limit)
-        sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by}{limit};"
+        sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         
         dependency_key = self.__get_dependency_key(str(dependency_key))
         cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key('*',where,group_by,order_by,limit,params)
