@@ -2,8 +2,8 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2021-12-13 16:20:43
-@LastEditors: WangQiang
+@LastEditTime: 2021-12-15 17:11:00
+@LastEditors: HuangJianYi
 @Description: 
 """
 
@@ -20,7 +20,7 @@ class ErpConsoleModel():
     """
     :description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流)
     """
-    def console_erp(self, mod_count=10):
+    def console_erp(self, mod_count=1):
         """
         :description: 控制台推送订单和回写物流
         :param mod_count: 单表队列数
@@ -56,7 +56,10 @@ class ErpConsoleModel():
         while True:
             try:
                 now_date = TimeHelper.get_now_format_time()
-                erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                if mod_count == 1:
+                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                else:
+                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                 if len(erp_relation_list) > 0:
                     for erp_relation_dict in erp_relation_list:
                         try:
@@ -87,7 +90,7 @@ class ErpConsoleModel():
                             logger_error.error(f"推送订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                             continue
                 else:
-                    time.sleep(1)
+                    time.sleep(60)
             except Exception as ex:
                 time.sleep(5)
 
@@ -175,7 +178,10 @@ class ErpConsoleModel():
         while True:
             try:
                 now_date = TimeHelper.get_now_format_time()
-                erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                if mod_count == 1:
+                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                else:
+                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                 if len(erp_relation_list) > 0:
                     for erp_relation_dict in erp_relation_list:
                         try:
@@ -214,6 +220,6 @@ class ErpConsoleModel():
                             logger_error.error(f"拉取订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                             continue
                 else:
-                    time.sleep(1)
+                    time.sleep(60)
             except Exception as ex:
                 time.sleep(5)
\ No newline at end of file
