@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-11-12 09:55:46
+@LastEditTime: 2021-11-18 14:30:13
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -212,11 +212,16 @@ class FrameBaseModel():
         user_info_model = UserInfoModel(context=self.context)
         id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
         user_info_dict = user_info_model.get_cache_dict("id_md5=%s",params=[id_md5],dependency_key=f"user_info:actid_{act_id}_idmd5_{id_md5}")
-        if user_info_dict and user_info_dict["app_id"] != app_id:
+        if not user_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_user"
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
+        if user_info_dict["app_id"] != app_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "no_power"
+            invoke_result_data.error_message = "用户信息不存在"
+            return invoke_result_data
         if user_info_dict["user_state"] == 1:
             invoke_result_data.success = False
             invoke_result_data.error_code = "user_exception"
