@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-11-29 19:09:14
+@LastEditTime: 2021-11-29 20:42:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -751,18 +751,19 @@ class OrderBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def get_horseracelamp_list(self,act_id,module_id,page_size=30):
+    def get_horseracelamp_list(self,act_id,module_id,is_search_module=False,page_size=30):
         """
         :description: 获取跑马灯奖品列表
         :param act_id:活动标识
         :param module_id:活动模块标识
+        :param is_search_module:是否查询活动模块
         :param page_size：页大小
         :return list
         :last_editors: HuangJianYi
         """
         condition = "act_id=%s"
         params = [act_id]
-        if module_id:
+        if is_search_module == True and module_id:
             condition+= " and module_id=%s"
             params.append(module_id)
         act_prize_list_dict = ActPrizeModel(context=self.context).get_cache_list("act_id=%s and is_prize_notice=0 and is_del=0", params=[act_id],cache_expire=60)
@@ -786,47 +787,46 @@ class OrderBaseModel(FrameBaseModel):
                     else:
                         user_nick = prize_roster_list[i]["user_nick"][0:1] + "*"
                     prize_roster_list[i]["user_nick"] = user_nick
+        act_module_list = []
         if total < page_size:
-            module_condition = "act_id=%s and is_fictitious=1"
-            module_params = [act_id]
-            if module_id > 0:
-                module_condition += " and id=%s"
-                module_params = [act_id, module_id]
-            act_module_list = ActModuleModel(context=self.context).get_cache_list(module_condition, params=module_params,cache_expire=60)
-            if len(act_module_list) > 0:
-                module_id_list = [str(i.id) for i in act_module_list]
-                module_ids = ",".join(module_id_list)
-                add_num = page_size - total
-                act_prize_model = ActPrizeModel(context=self.context)
-                prize_condition = "act_id=%s and is_prize_notice=1"
-                prize_params = [act_id]
-                if module_id > 0:
-                    prize_condition += " and module_id=%s"
-                    prize_params.append(module_id)
-                else:
-                    prize_condition += " and module_id in (" + module_ids + ")"
-                false_act_prize_list = act_prize_model.get_cache_list(prize_condition, order_by="probability desc,chance desc", limit="30", params=prize_params,cache_expire=60)
-                if len(false_act_prize_list) > 0 and add_num > 0:
-                    now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
-                    user_info_list_dict = UserInfoModel(context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
+            add_num = page_size - total
+            act_prize_model = ActPrizeModel(context=self.context)
+            prize_condition = "act_id=%s and is_prize_notice=1"
+            prize_params = [act_id]
 
-                    for i in range(len(user_info_list_dict)):
-                        false_act_prize = false_act_prize_list[random.randint(0, len(false_act_prize_list))]
-                        if len(false_act_prize) <= 0:
-                            continue
-                        prize_roster = {}
-                        if user_info_list_dict[i]["user_nick"]:
-                            length = len(user_info_list_dict[i]["user_nick"])
-                            if length > 2:
-                                user_nick = user_info_list_dict[i]["user_nick"][0:length - 2] + "**"
-                            else:
-                                user_nick = user_info_list_dict[i]["user_nick"][0:1] + "*"
-                        prize_roster["user_nick"] = user_nick
-                        prize_roster["prize_name"] = false_act_prize.prize_name
-                        prize_roster["tag_id"] = false_act_prize.tag_id
-                        act_module_filter = [act_module for act_module in act_module_list if false_act_prize.module_id == act_module.id]
-                        prize_roster["module_name"] = act_module_filter[0].module_name if len(act_module_filter) > 0 else ""
-                        prize_roster_list.append(prize_roster)
+            if is_search_module == True:
+                module_condition = "act_id=%s and is_fictitious=1"
+                module_params = [act_id]
+                if module_id >0:
+                    module_condition += " and id=%s"
+                    module_params = [act_id, module_id]
+                act_module_list = ActModuleModel(context=self.context).get_cache_list(module_condition, params=module_params,cache_expire=60)
+                if len(act_module_list) > 0:
+                    module_id_list = [str(i.id) for i in act_module_list]
+                    module_ids = ",".join(module_id_list)
+                    prize_condition += " and module_id in (" + module_ids + ")"
+            false_act_prize_list = act_prize_model.get_cache_list(prize_condition, order_by="probability desc,chance desc", limit="30", params=prize_params,cache_expire=60)
+            if len(false_act_prize_list) > 0 and add_num > 0:
+                now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
+                user_info_list_dict = UserInfoModel(context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
+
+                for i in range(len(user_info_list_dict)):
+                    false_act_prize = false_act_prize_list[random.randint(0, len(false_act_prize_list)-1)]
+                    if not false_act_prize:
+                        continue
+                    prize_roster = {}
+                    if user_info_list_dict[i]["user_nick"]:
+                        length = len(user_info_list_dict[i]["user_nick"])
+                        if length > 2:
+                            user_nick = user_info_list_dict[i]["user_nick"][0:length - 2] + "**"
+                        else:
+                            user_nick = user_info_list_dict[i]["user_nick"][0:1] + "*"
+                    prize_roster["user_nick"] = user_nick
+                    prize_roster["prize_name"] = false_act_prize.prize_name
+                    prize_roster["tag_id"] = false_act_prize.tag_id
+                    act_module_filter = [act_module for act_module in act_module_list if false_act_prize.module_id == act_module.id]
+                    prize_roster["module_name"] = act_module_filter[0].module_name if len(act_module_filter) > 0 else ""
+                    prize_roster_list.append(prize_roster)
         
         return prize_roster_list
         
\ No newline at end of file
