@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-12-20 16:04:44
+@LastEditTime: 2021-12-21 15:20:21
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -72,27 +72,33 @@ class TopBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起,请先授权登录"
             return invoke_result_data
-        store_user_nick = user_nick.split(':')[0]
         app_info = app_info_model.get_cache_entity(where="store_user_nick=%s", params=store_user_nick)
         # 有效时间获取
-        invoke_result_data = self.get_dead_date(store_user_nick, access_token,app_key,app_secret, is_log)
+        invoke_result_data = self.get_dead_date(store_user_nick, access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             return invoke_result_data
         dead_date = invoke_result_data.data
         if app_info:
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
+            invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+            if invoke_result_data.success == True:
                 app_info.access_token = access_token
             app_info_model.update_entity(app_info, "expiration_date,access_token")
             invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token}
             return invoke_result_data
 
-        if ":" in user_nick:
-            invoke_result_data.success = False
-            invoke_result_data.error_code = "account_error"
-            invoke_result_data.error_message = "对不起，初次创建活动包含实例化，请使用主账号进行创建。"
-            return invoke_result_data
+        # if ":" in user_nick:
+        #     invoke_result_data.success = False
+        #     invoke_result_data.error_code = "account_error"
+        #     invoke_result_data.error_message = "对不起，初次创建活动包含实例化，请使用主账号进行创建。"
+        #     return invoke_result_data
 
+        invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+        if invoke_result_data.success == False:
+            invoke_result_data.error_code = "account_error"
+            invoke_result_data.error_message = "对不起，请使用主账号或者授权的子账号进行创建"
+            return invoke_result_data
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateInstantiateRequest()
